# `VenomSeq`
A next-generation sequencing workflow for discovering therapeutic associations between venoms and human disease.

[![Build Status](https://travis-ci.com/JDRomano2/venomseq.svg?branch=master)](https://travis-ci.com/JDRomano2/venomseq)
[![Coverage Status](https://coveralls.io/repos/github/JDRomano2/venomseq/badge.svg?branch=master)](https://coveralls.io/github/JDRomano2/venomseq?branch=master)
- - -
## What is this?
Venoms provide an incredible opportunity for drug discovery. Over the course of human history, thousands of therapeutic uses for venoms have been discovered, and recent decades have seen a number of these be turned into FDA-approved drugs. However, most of these effects were discovered accidentally, and the rest were only found as the result of decades of systematic research.

`VenomSeq` is a tool that aims to change this, providing a new way to generate high-thoughput sequencing data for perturbational differential expression analysis of venoms applied to human cell lines in a scalable, inexpensive manner.

We are preparing a preprint describing `VenomSeq` in-depth, and will post a link here as soon as one is available.

This python package contains the algorithms and data structures needed for analyzing the data generated by `VenomSeq`.
- - -
## System requirements
`VenomSeq` has been tested with Python 3.6 on both MacOS 10.14.2 and Windows 10. If you would like to help us test on currently unsupported platforms, please submit an issue or pull request.
- - -
## Installing
From source:
```
git clone https://github.com/JDRomano2/venomseq
cd venomseq
pip3 install .
```
From PyPI:
```
pip3 install venomseq
```

- - -
## Running an example
The Jupyter Notebook file located at `doc/examples/Visualizations.ipynb` provides an example of loading an existing `VenomSeq` analysis into memory and creating several visualizations that explain the results. Users will have to download several (large) external files containing the processed data and metadata (which are too large to include in the source distribution).